from importlib import resources
from shutil import copyfile
import os

import pandas as pd


def load(file):
    # Get absolute path to data
    data_path = resources.files("jrpyprogramming") / "data"

    # List data sources in package
    files = os.listdir(data_path)

    # Map from filename (without) extension, to file name with extension
    files_w_ext = {data.split(".")[0]: data for data in files}

    # Ensure file is available
    assert file in files_w_ext, \
        (f"Dataset {file} not found. "
          "Available files are: "
         f"{', '.join(list(files_w_ext.keys())[:-1])} "
         f"and {list(files_w_ext.keys())[-1]}.")

    # Get file with appropriate extension from list of available
    file_w_ext = files_w_ext[file]

    # Get absolute path to file
    abs_path = data_path / file_w_ext

    return pd.read_csv(abs_path)


def populate_examples():
    # Get absolute path to data
    data_path = resources.files("jrpyprogramming") / "data"

    # Get path to files relative to package
    pkg_data = os.listdir(data_path)

    # Only list files which have a name which starts with "data"
    files = [file for file in pkg_data if file.startswith('data')]

    # Copy files to current dir
    for file in files:
        abs_path = data_path / file
        copyfile(abs_path, file)
        print(f'\nCreated file {file} in current directory.\n')
